==> haskell-here-1.2.13-36-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: here
version: 1.2.13
id: here-1.2.13-DCAeCPb8sfxGHnFIpJjVsd
key: here-1.2.13-DCAeCPb8sfxGHnFIpJjVsd
license: BSD-3-Clause
copyright: ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer: t@tmh.cc
author: Taylor M. Hedberg
homepage: https://github.com/tmhedberg/here
synopsis: Here docs & interpolated strings via quasiquotation
description:
    Here docs & interpolated strings via quasiquotation
category: Data
abi: 0583ccfbaf69a5f3dc19f0670dc8c251
exposed: True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated
hidden-modules: Data.String.Here.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/here-1.2.13
library-dirs: /usr/lib/ghc-8.4.3/site-local/here-1.2.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/here-1.2.13
hs-libraries: HShere-1.2.13-DCAeCPb8sfxGHnFIpJjVsd
depends:
    base-4.11.1.0 haskell-src-meta-0.8.0.3-HwMp7B5kMNQGcpqxYLNyJ2
    mtl-2.2.2 parsec-3.1.13.0 template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             haskell-src-meta-0.8.0.3-HwMp7B5kMNQGcpqxYLNyJ2=7fe0e668d2ed958edb52a7dde8d7d38f
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-here/html/here.haddock
haddock-html: /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-here-1.2.13-37-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: here
version: 1.2.13
id: here-1.2.13-EnPv9SWjupj66vyFKtj2NA
key: here-1.2.13-EnPv9SWjupj66vyFKtj2NA
license: BSD-3-Clause
copyright: ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer: t@tmh.cc
author: Taylor M. Hedberg
homepage: https://github.com/tmhedberg/here
synopsis: Here docs & interpolated strings via quasiquotation
description:
    Here docs & interpolated strings via quasiquotation
category: Data
abi: 95ee5610dec9f96ae42c22f135fbb368
exposed: True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated
hidden-modules: Data.String.Here.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/here-1.2.13
library-dirs: /usr/lib/ghc-8.4.3/site-local/here-1.2.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/here-1.2.13
hs-libraries: HShere-1.2.13-EnPv9SWjupj66vyFKtj2NA
depends:
    base-4.11.1.0 haskell-src-meta-0.8.0.3-1XlNXesbWzl1eqjFosN2vJ
    mtl-2.2.2 parsec-3.1.13.0 template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             haskell-src-meta-0.8.0.3-1XlNXesbWzl1eqjFosN2vJ=e7b866c6a3c53f9bffa3f491f2113747
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-here/html/here.haddock
haddock-html: /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
